@@ -52,6 +52,17 @@ legacy_run2_b2jpsieek_stripping_datasets = {
   'MagUp_2018'  : ['root://eoslhcb.cern.ch//eos/lhcb/wg/PID/PIDCalib_2018_electrons/Turbo2018_B2KJpsiEE_MagUp.root'], 
 }
 
+run2_lb2lcpi_stripping_datasets = {
+  'MagDown_2015': ['root://eoslhcb.cern.ch//eos/lhcb/wg/PID/PIDGen2/calibration/proton/lcpi_splot_exp15_md.root'],
+  'MagDown_2016': ['root://eoslhcb.cern.ch//eos/lhcb/wg/PID/PIDGen2/calibration/proton/lcpi_splot_exp16_md.root'],
+  'MagDown_2017': ['root://eoslhcb.cern.ch//eos/lhcb/wg/PID/PIDGen2/calibration/proton/lcpi_splot_exp17_md.root'],
+  'MagDown_2018': ['root://eoslhcb.cern.ch//eos/lhcb/wg/PID/PIDGen2/calibration/proton/lcpi_splot_exp18_md.root'],
+  'MagUp_2015': ['root://eoslhcb.cern.ch//eos/lhcb/wg/PID/PIDGen2/calibration/proton/lcpi_splot_exp15_mu.root'],
+  'MagUp_2016': ['root://eoslhcb.cern.ch//eos/lhcb/wg/PID/PIDGen2/calibration/proton/lcpi_splot_exp16_mu.root'],
+  'MagUp_2017': ['root://eoslhcb.cern.ch//eos/lhcb/wg/PID/PIDGen2/calibration/proton/lcpi_splot_exp17_mu.root'],
+  'MagUp_2018': ['root://eoslhcb.cern.ch//eos/lhcb/wg/PID/PIDGen2/calibration/proton/lcpi_splot_exp18_mu.root']
+}
+
 converted_run1_pidcalib_datasets_dstar_k = {
   "MagUp_2011"   : [f"{run1_dir}/MagUp/DSt_K_MagUp_Strip21r1_{i}.root" for i in range(24) ], 
   "MagUp_2012"   : [f"{run1_dir}/MagUp/DSt_K_MagUp_Strip21_{i}.root" for i in range(72) ], 
@@ -73,6 +84,34 @@ converted_run1_pidcalib_datasets_lam0_p = {
   "MagDown_2012" : [f"{run1_dir}/MagDown/Lam0_P_MagDown_Strip21_{i}.root" for i in range(121) ], 
 }
 
+converted_run1_pidcalib_datasets_lblcmu_p = {
+  "MagUp_2011"   : [f"{run1_dir}/MagUp/LcfB_P_MagUp_Strip21r1_{i}.root" for i in range(1) ], 
+  "MagUp_2012"   : [f"{run1_dir}/MagUp/LcfB_P_MagUp_Strip21_{i}.root" for i in range(3) ], 
+  "MagDown_2011" : [f"{run1_dir}/MagDown/LcfB_P_MagDown_Strip21r1_{i}.root" for i in range(2) ], 
+  "MagDown_2012" : [f"{run1_dir}/MagDown/LcfB_P_MagDown_Strip21_{i}.root" for i in range(3) ], 
+}
+
+converted_run1_pidcalib_datasets_inclc_p = {
+  "MagUp_2011"   : [f"{run1_dir}/MagUp/IncLc_P_MagUp_Strip21r1_{i}.root" for i in range(1) ], 
+  "MagUp_2012"   : [f"{run1_dir}/MagUp/IncLc_P_MagUp_Strip21_{i}.root" for i in range(3) ], 
+  "MagDown_2011" : [f"{run1_dir}/MagDown/IncLc_P_MagDown_Strip21r1_{i}.root" for i in range(2) ], 
+  "MagDown_2012" : [f"{run1_dir}/MagDown/IncLc_P_MagDown_Strip21_{i}.root" for i in range(3) ], 
+}
+
+converted_run1_pidcalib_datasets_jpsimumu = {
+  'MagUp_2011'   : [f"{run1_dir}/MagUp/Jpsi_Mu_MagUp_Strip21r1_{i}.root" for i in range(7+1) ], 
+  'MagUp_2012'   : [f"{run1_dir}/MagUp/Jpsi_Mu_MagUp_Strip21_{i}.root" for i in range(81+1) ], 
+  'MagDown_2011' : [f"{run1_dir}/MagDown/Jpsi_Mu_MagDown_Strip21r1_{i}.root" for i in range(11+1) ],
+  'MagDown_2012' : [f"{run1_dir}/MagDown/Jpsi_Mu_MagDown_Strip21_{i}.root" for i in range(79+1) ], 
+}
+
+converted_run1_pidcalib_datasets_jpsimumunopt = {
+  'MagUp_2011'   : [f"{run1_dir}/MagUp/Jpsi_Mu_nopt_MagUp_Strip21r1_2011.root"], 
+  'MagUp_2012'   : [f"{run1_dir}/MagUp/Jpsi_Mu_nopt_MagUp_Strip21_2012.root"], 
+  'MagDown_2011' : [f"{run1_dir}/MagDown/Jpsi_Mu_nopt_MagDown_Strip21r1_2011.root"],
+  'MagDown_2012' : [f"{run1_dir}/MagDown/Jpsi_Mu_nopt_MagDown_Strip21_2012.root"], 
+}
+
 photon_run1_datasets_kstargamma = {
   "2011-2012" : [f"{photon_dir}/sWtd_run0_mode0.root"], 
 }
@@ -85,18 +124,6 @@ photon_run1_datasets_kstargamma_partreco_type1 = {
   "2011-2012" : [f"{photon_dir}/sWtd_run0_mode0_partreco_type1.root"], 
 }
 
-photon_run1_datasets_kstargamma_partreco_type0_region0 = {
-  "2011-2012" : [f"{photon_dir}/sWtd_run0_mode0_partreco_type0_region0.root"], 
-}
-
-photon_run1_datasets_kstargamma_partreco_type0_region1 = {
-  "2011-2012" : [f"{photon_dir}/sWtd_run0_mode0_partreco_type0_region1.root"], 
-}
-
-photon_run1_datasets_kstargamma_partreco_type0_region2 = {
-  "2011-2012" : [f"{photon_dir}/sWtd_run0_mode0_partreco_type0_region2.root"], 
-}
-
 photon_run2_datasets_kstargamma = {
   "2016" : [f"{photon_dir}/sWtd_run1_mode0.root"], 
   "2017" : [f"{photon_dir}/sWtd_run2_mode0.root"], 
@@ -114,21 +141,3 @@ photon_run2_datasets_kstargamma_partreco_type1 = {
   "2017" : [f"{photon_dir}/sWtd_run2_mode0_partreco_type1.root"], 
   "2018" : [f"{photon_dir}/sWtd_run3_mode0_partreco_type1.root"], 
 }
-
-photon_run2_datasets_kstargamma_partreco_type0_region0 = {
-  "2016" : [f"{photon_dir}/sWtd_run1_mode0_partreco_type0_region0.root"], 
-  "2017" : [f"{photon_dir}/sWtd_run2_mode0_partreco_type0_region0.root"], 
-  "2018" : [f"{photon_dir}/sWtd_run3_mode0_partreco_type0_region0.root"], 
-}
-
-photon_run2_datasets_kstargamma_partreco_type0_region1 = {
-  "2016" : [f"{photon_dir}/sWtd_run1_mode0_partreco_type0_region1.root"], 
-  "2017" : [f"{photon_dir}/sWtd_run2_mode0_partreco_type0_region1.root"], 
-  "2018" : [f"{photon_dir}/sWtd_run3_mode0_partreco_type0_region1.root"], 
-}
-
-photon_run2_datasets_kstargamma_partreco_type0_region2 = {
-  "2016" : [f"{photon_dir}/sWtd_run1_mode0_partreco_type0_region2.root"], 
-  "2017" : [f"{photon_dir}/sWtd_run2_mode0_partreco_type0_region2.root"], 
-  "2018" : [f"{photon_dir}/sWtd_run3_mode0_partreco_type0_region2.root"], 
-}
