@@ -68,16 +68,27 @@ kernels = [
 
 config = {
   'h' :    {
-            "ProbNNK"    : ("ProbNNK", "pi_Dstar2Dpi", "MC15TuneV1_ProbNNK", kernels),
+            "ProbNNK"    : ("ProbNNK",  "pi_Dstar2Dpi", "MC15TuneV1_ProbNNK", kernels),
             "ProbNNpi"   : ("ProbNNpi", "pi_Dstar2Dpi", "MC15TuneV1_ProbNNpi", kernels),
+            "ProbNNp"    : ("ProbNNp",  "pi_Dstar2Dpi", "MC15TuneV1_ProbNNp", kernels),
            },
   'lpi' :  {
-            "ProbNNK"    : ("ProbNNK", "pi_Dstar2Dpi", "MC15TuneV1_ProbNNK", kernels),
+            "ProbNNK"    : ("ProbNNK",  "pi_Dstar2Dpi", "MC15TuneV1_ProbNNK", kernels),
             "ProbNNpi"   : ("ProbNNpi", "pi_Dstar2Dpi", "MC15TuneV1_ProbNNpi", kernels),
+            "ProbNNp"    : ("ProbNNp",  "pi_Dstar2Dpi", "MC15TuneV1_ProbNNp", kernels),
            },
   'lk' :   {
-            "ProbNNK"    : ("ProbNNK", "K_Dstar2Dpi", "MC15TuneV1_ProbNNK", kernels),
+            "ProbNNK"    : ("ProbNNK",  "K_Dstar2Dpi", "MC15TuneV1_ProbNNK", kernels),
             "ProbNNpi"   : ("ProbNNpi", "K_Dstar2Dpi", "MC15TuneV1_ProbNNpi", kernels),
+            "ProbNNp"    : ("ProbNNp",  "K_Dstar2Dpi", "MC15TuneV1_ProbNNp", kernels),
+           },
+  'lp' :   {
+            "ProbNNK"    : ("ProbNNK",  "p_Lambda2ppi", "MC15TuneV1_ProbNNK", kernels),
+            "ProbNNpi"   : ("ProbNNpi", "p_Lambda2ppi", "MC15TuneV1_ProbNNpi", kernels),
+            "ProbNNp"    : ("ProbNNp",  "p_Lambda2ppi", "MC15TuneV1_ProbNNp", kernels),
+            "prProbNNK"  : ("ProbNNK",  "p_Lambda2ppi_Prompt", "MC15TuneV1_ProbNNK", kernels),
+            "prProbNNpi" : ("ProbNNpi", "p_Lambda2ppi_Prompt", "MC15TuneV1_ProbNNpi", kernels),
+            "prProbNNp"  : ("ProbNNp",  "p_Lambda2ppi_Prompt", "MC15TuneV1_ProbNNp", kernels),
            },
 }
 
@@ -126,6 +137,9 @@ for input_file, output_file, dataset in files :
          verbose = False,           # Print debugging information
          eta_from_p = eta_from_p,   # If eta needs to be calculated from p and pt
          friend = friend,           # If True, write output to friend trees
+         library = "ak",            # Library to handle ROOT files with uproot if friend=False, can be 
+                                    # "ak" (Awkward array), "np" (numpy) or "pd" (Pandas)
+         step_size = 50000,         # Chunk size when writing files with uproot if friend=False
          nan = -1000.,              # Numerical value to substitute NaN, for regions w/o calibration data 
          scale = scale,             # Scale factors for input data 
          local_storage = "./templates/",  # Directory for local template storage, used when the template is not available in 
