@@ -15,3 +15,7 @@
 from jax.config import config
 config.update("jax_enable_x64", True)  # double precision in jax by default
 config.update('jax_platform_name', 'cpu')
+
+from warnings import simplefilter
+import pandas as pd
+simplefilter(action="ignore", category=pd.errors.PerformanceWarning)
