@@ -20,7 +20,7 @@ import numpy as onp
 import uproot
 from scipy.ndimage import gaussian_filter
 
-from .tuples import write_array, read_array
+from .tuples import write_array, write_friend_array, read_array
 from .resampling import read_calib_tuple, calib_transform, data_transform, get_or_create_template, resample_data
 from .resampling import get_samples, get_variables
 
@@ -44,6 +44,8 @@ def resample(
     kernels = None, 
     verbose = False, 
     friend = False, 
+    library = "ak", 
+    step_size = 100000, 
     local_storage = "/eos/lhcb/wg/PID/PIDGen2/templates/", 
     global_storage = "root://eoslhcb.cern.ch//eos/lhcb/wg/PID/PIDGen2/templates/", 
     cachedir = None, 
@@ -55,10 +57,16 @@ def resample(
   input_branches = branches.split(":")
 
   config = get_samples()[sample][dataset]
-  vardef = get_variables()[variable]
 
   pp = pprint.PrettyPrinter(indent = 4)
 
+  if "aliases" in config and variable in config["aliases"] : 
+    aliased_variable = config["aliases"][variable]
+    print(f"Using alias '{aliased_variable}' for variable name '{variable}' in dataset '{dataset}', sample '{sample}'")
+    variable = aliased_variable
+
+  vardef = get_variables()[variable]
+
   if (verbose) : 
     print(f"Calibration sample config: {pp.pformat(config)}")
     print(f"Variable definition: {pp.pformat(vardef)}")
@@ -91,12 +99,9 @@ def resample(
     # Replace momentum by eta calculated from p and pT
     input_data[:,1] = -np.log(np.tan(np.arcsin(input_data[:,0]/input_data[:,1])/2.))
 
-  if not friend : 
-    all_df = uproot.concatenate(input, library = "pd")
-    all_branches = list(all_df.keys())
-    all_data = all_df[all_branches].to_numpy()[start_event:stop_event].astype(np.float64)
-    if (verbose) : 
-      print (f"Shape of all input data array: {all_data.shape}")
+  if not friend :
+    if (verbose) :
+      all_branches = list(uproot.open(input).keys())
       print (f"List of all input tree branches: {pp.pformat(all_branches)}")
 
   # Loop over kernels
@@ -173,10 +178,11 @@ def resample(
   # End of loop over kernels
 
   if not friend : 
-    write_array(output, np.concatenate([all_data] + output_arrays, axis = 1), 
-            branches = all_branches + output_branches, tree = outtree )
+    write_array(output, np.concatenate(output_arrays, axis = 1),
+            branches = output_branches, input = input, tree = outtree, step_size = step_size, 
+            library = library, verbose = verbose)
   else : 
-    write_array(output, np.concatenate(output_arrays, axis = 1), 
+    write_friend_array(output, np.concatenate(output_arrays, axis = 1), 
             branches = output_branches, tree = outtree )
 
 def main() : 
@@ -222,6 +228,10 @@ def main() :
                       help='Enable debug messages')
   parser.add_argument('--friend', default = False, action = "store_const", const = True, 
                       help='Create friend tree with only resampled PID and statistics branches')
+  parser.add_argument('--library', type=str, default = "ak", choices = ["ak", "np", "pd"], 
+                      help='Library to handle ROOT ntuples with uproot')
+  parser.add_argument('--step_size', type=int, default = 100000, 
+                      help='Chunk size for ROOT file writing with uproot')
   parser.add_argument('--local_storage', type=str, default = "/eos/lhcb/wg/PID/PIDGen2/templates/", 
                       help="Local template storage directory")
   parser.add_argument('--global_storage', type=str, default = "root://eoslhcb.cern.ch//eos/lhcb/wg/PID/PIDGen2/templates/", 
