@@ -278,7 +278,11 @@ def calib_transform(x, config, variable) :
     else : 
       xs = x[:,i+1]
     arr += [ t(xs) ]
-  arr += [ x[:,-1] ] # sWeight
+
+  if x.shape[1] > len(transform_sample)+1 : 
+    arr += [ x[:,-1] ] # sWeight
+  else : 
+    arr += [ np.ones_like(x[:,0]) ] # No sWeight, make unit weights
 
   return np.stack(arr, axis = 1)
 
@@ -315,9 +319,11 @@ def store_to_cache(variable, config, max_files = 0, verbose = False, cachedir =
   """
   sample = config['sample']
   trees = config['trees']
-  expressions = [variable["expression"]] + config["branches"]
+
+  track_prefix = config.get("prefix", "probe") + "_"
+  expressions = [variable["expression"].replace("probe_", track_prefix)] + config["branches"]
   if "branches" in variable :
-    calib_branches = variable["branches"] + config["branches"]
+    calib_branches = [v.replace("probe_", track_prefix) for v in variable["branches"]] + config["branches"]
   else : 
     calib_branches = expressions
 
@@ -347,7 +353,7 @@ def get_hash_config(sample_name, dataset_name, variable_name, variable, config,
   }
 
   # Remove keys that raw (unsmeared) template does not depend on
-  config_keys_to_ignore = ["labels", "template_sigma", "variables"]
+  config_keys_to_ignore = ["labels", "template_sigma", "variables", "aliases"]
   variable_keys_to_ignore = ["template_sigma"]
   if not mc : variable_keys_to_ignore += ["mc_expression"]
 
@@ -405,7 +411,7 @@ def get_or_create_template(sample_name, dataset_name, variable_name,
 
     except FileNotFoundError : 
 
-      print(f"Template in local storage {truncate_middle(template_storage, 80)} not found, will create one. Be patient...")
+      print(f"Template in local storage {truncate_middle(template_storage, 80)} not found.")
 
   else : 
     if local_prefix == None : 
@@ -441,6 +447,10 @@ def get_or_create_mc_template(sim_version, sample_name, dataset_name, variable_n
   """
 
   """
+  if (verbose) : 
+    print(f"Variable definition: {variable}")
+    print(f"Sample config: {config}")
+
   hash_config = get_hash_config(sample_name, dataset_name, variable_name, variable, config, max_files, mc = True)
   config_hash = sha1(str(hash_config).encode('utf-8')).hexdigest()
 
@@ -762,7 +772,14 @@ def create_template_multipass(variable, config, kernels = None, use_calib_cache
 
   track_prefix = config.get("prefix")
   if not mc : 
-    expressions = [variable["expression"].format(prefix = track_prefix)]
+    if variable["expression"].find("{prefix}")>=0 : 
+      expressions = [variable["expression"].format(prefix = track_prefix)]
+    else : 
+      if track_prefix : 
+        # Fix for Lb2Lcpi sample, where track prefix differs from "probe"
+        expressions = [ variable["expression"].replace("probe_", track_prefix+"_") ]
+      else : 
+        expressions = [ variable["expression"] ]
     if "branches" in variable :
       calib_branches = [ v.format(prefix = track_prefix) for v in variable["branches"]]
     else : 
@@ -781,6 +798,10 @@ def create_template_multipass(variable, config, kernels = None, use_calib_cache
     expressions += config["branches"]
     calib_branches += config["branches"]
 
+  if (verbose) : 
+    print(f"Expressions: {expressions}")
+    print(f"Calib branches: {calib_branches}")
+
   ranges = [ variable["data_range"]] + config["data_ranges"]
   calib_cache_branches = ["pid"] + config["calib_cache_branches"]
   normalise_bins = [variable["normalise_bins"]] + config["normalise_bins"]
@@ -844,7 +865,7 @@ def create_template_multipass(variable, config, kernels = None, use_calib_cache
       if data is None : continue
       data = calib_transform(data, config, variable)
       data = de.filter_data(data, ranges + [ (-1000., 1000.) ] )
-      histograms = de.append_histograms(data, ranges = ranges, bins = normalise_bins, weights = data[:,-1])
+      histograms = de.append_histograms(data, ranges = ranges, bins = normalise_bins, hists = histograms, weights = data[:,-1])
 
   print(f"\nRead {len(sample)} calibration subsamples from remote storage.")
 
@@ -854,6 +875,7 @@ def create_template_multipass(variable, config, kernels = None, use_calib_cache
   else : 
     print(f"Creating normaliser structure")
     normaliser = de.create_normaliser_from_histograms(histograms)
+  if (verbose) : print(f"Normaliser: {normaliser}")
 
   print(f"Pass: filling resampling template")
 
