@@ -14,6 +14,17 @@ from ..datasets import legacy_run2_pidcalib_datasets as ds_run2
 
 from itertools import product
 
+probnn_responses = ["pi", "K", "p", "e", "mu", "piNotK", "piNotKp", "KNotpi", "KNotpip", "pNotK", "pNotpiK"]
+
+def brunel_aliases(year) : 
+    """
+      Define aliases for Brunel variables in 2017, 2018 samples
+      to point to Online versions. 
+    """
+    if year in ["2017", "2018"] : 
+        return { "Brunel_MC15TuneV1_ProbNN" + var : "MC15TuneV1_ProbNN" + var for var in probnn_responses }
+    else : return {}
+
 common_params = {
     "calib_cache_branches" : ["pt", "eta", "ntr", "sw"],          # Names of variable branches in ROOT tree of the cache file 
     "data_ranges" : [ (2.4, 4.4), (1.9, 5.0), (0.7, 3.1) ],       # Ranges of each variable after transformation
@@ -46,14 +57,9 @@ sample_run2 = {
       "probe_sWeight" 
     ], 
     "trees" : ['DSt_KMTuple/DecayTree'], 
-    "variables" : [
-                   "CombDLLK", "CombDLLmu", "CombDLLe", "CombDLLp", 
-                   "MC15TuneV1_ProbNNpi", "MC15TuneV1_ProbNNK", "MC15TuneV1_ProbNNp", 
-                   "MC15TuneV1_ProbNNe", "MC15TuneV1_ProbNNmu", 
-                   "MC15TuneV1_ProbNNpiNotK", "MC15TuneV1_ProbNNpiNotKp", 
-                   "MC15TuneV1_ProbNNKNotpi", "MC15TuneV1_ProbNNKNotpip", 
-                   "MC15TuneV1_ProbNNpNotK", "MC15TuneV1_ProbNNpNotpiK", 
-                  ], 
+    "variables" : ["CombDLLK", "CombDLLmu", "CombDLLe", "CombDLLp"] + 
+                  [ f"{b}MC15TuneV1_ProbNN{i}" for b, i in product(["", "Brunel_"], probnn_responses) ], 
+    "aliases" : brunel_aliases(year), 
     **common_params, 
   } 
   for pol in ["MagUp", "MagDown"] for year in ["2015", "2016", "2017", "2018"]
@@ -69,15 +75,9 @@ sample_run1 = {
       "probe_sWeight" 
     ], 
     "trees" : ['DecayTree'], 
-    "variables" : [
-                   "CombDLLK", "CombDLLmu", "CombDLLe", "CombDLLp", 
-                   "MC12TuneV2_ProbNNpi", "MC12TuneV2_ProbNNK", "MC12TuneV2_ProbNNp", 
-                   "MC12TuneV3_ProbNNpi", "MC12TuneV3_ProbNNK", "MC12TuneV3_ProbNNp", 
-                   "MC12TuneV3_ProbNNe", "MC12TuneV3_ProbNNmu", 
-                   "MC12TuneV3_ProbNNpiNotK", "MC12TuneV3_ProbNNpiNotKp", 
-                   "MC12TuneV3_ProbNNKNotpi", "MC12TuneV3_ProbNNKNotpip", 
-                   "MC12TuneV3_ProbNNpNotK", "MC12TuneV3_ProbNNpNotpiK", 
-                  ], 
+    "variables" : ["CombDLLK", "CombDLLmu", "CombDLLe", "CombDLLp", 
+                   "MC12TuneV2_ProbNNpi", "MC12TuneV2_ProbNNK", "MC12TuneV2_ProbNNp"] + 
+                  [f"MC12TuneV3_ProbNN{i}" for i in probnn_responses ], 
     "cut" : "probe_trackcharge<0", 
     **common_params, 
   } 
