@@ -49,9 +49,6 @@ sample_run2 = {
                    "CombDLLK", "CombDLLmu", "CombDLLe", "CombDLLp", 
                    "MC15TuneV1_ProbNNpi", "MC15TuneV1_ProbNNK", "MC15TuneV1_ProbNNp", 
                    "MC15TuneV1_ProbNNe", "MC15TuneV1_ProbNNmu", 
-                   "MC15TuneV1_ProbNNpiNotK", "MC15TuneV1_ProbNNpiNotKp", 
-                   "MC15TuneV1_ProbNNKNotpi", "MC15TuneV1_ProbNNKNotpip", 
-                   "MC15TuneV1_ProbNNpNotK", "MC15TuneV1_ProbNNpNotpiK", 
                   ], 
     "cut" : "probe_Brunel_HasBremAdded==0", 
     **common_params, 
