@@ -11,7 +11,24 @@
 
 from ..datasets import legacy_run2_pidcalib_datasets as ds_run2
 from ..datasets import converted_run1_pidcalib_datasets_lam0_p as ds_run1
+from ..mc_datasets import lb2jpsipk_run2sim09_datsets as mc_run2sim09
+
 from itertools import product
+from copy import copy
+
+probnn_responses = ["pi", "K", "p", "e", "mu", "piNotK", "piNotKp", "KNotpi", "KNotpip", "pNotK", "pNotpiK"]
+
+def brunel_aliases(year) : 
+    """
+      Define aliases for Brunel variables in 2017, 2018 samples
+      to point to Online versions. 
+    """
+    if year in ["2017", "2018"] : 
+        return { "Brunel_MC15TuneV1_ProbNN" + var : "MC15TuneV1_ProbNN" + var for var in probnn_responses }
+    else : return {}
+
+probnn_responses_mc = ["pi", "K", "p"]
+brunel_aliases_mc = { "Brunel_MC15TuneV1_ProbNN" + var : "MC15TuneV1_ProbNN" + var for var in probnn_responses_mc }
 
 def trees(year) : 
   #return [ ("Lam0" + ("LL" if year in ["2017", "2018"] else "") + \
@@ -50,14 +67,9 @@ sample_run2 = {
       "probe_sWeight" 
     ], 
     "trees" : trees(year), 
-    "variables" : [
-                   "CombDLLK", "CombDLLmu", "CombDLLe", "CombDLLp", 
-                   "MC15TuneV1_ProbNNpi", "MC15TuneV1_ProbNNK", "MC15TuneV1_ProbNNp", 
-                   "MC15TuneV1_ProbNNe", "MC15TuneV1_ProbNNmu", 
-                   "MC15TuneV1_ProbNNpiNotK", "MC15TuneV1_ProbNNpiNotKp", 
-                   "MC15TuneV1_ProbNNKNotpi", "MC15TuneV1_ProbNNKNotpip", 
-                   "MC15TuneV1_ProbNNpNotK", "MC15TuneV1_ProbNNpNotpiK", 
-                  ], 
+    "variables" : ["CombDLLK", "CombDLLmu", "CombDLLe", "CombDLLp"] + 
+                  [ f"{b}MC15TuneV1_ProbNN{i}" for b, i in product(["", "Brunel_"], probnn_responses) ], 
+    "aliases" : brunel_aliases(year), 
     **common_params
   } 
   for pol in ["MagUp", "MagDown"] for year in ["2015", "2016", "2017", "2018"]
@@ -87,4 +99,26 @@ sample_run1 = {
   for pol in ["MagUp", "MagDown"] for year in ["2011", "2012"]
 }
 
+mc_params = copy(common_params)
+mc_params['max_weights'] = None
+
+mc_sample_run2 = {
+  f"Sim09_{pol}_{year}" : {
+    "sample" : mc_run2sim09[f"{pol}_{year}"], 
+    "prefix" : "p", 
+    "branches" : [
+      "p_PT", 
+      "p_ETA", 
+      "nTracks",
+    ], 
+    "trees" : ["lc/nt"], 
+    "variables" : [ f"{b}MC15TuneV1_ProbNN{i}" for b, i in product(["", "Brunel_"], probnn_responses_mc) ] + 
+                  ["CombDLLp", "CombDLLK"], 
+    "aliases" : brunel_aliases_mc, 
+    **mc_params, 
+  }
+  for pol in ["MagUp", "MagDown"] for year in ["2015", "2016", "2017", "2018"]
+}
+
 sample = {**sample_run1, **sample_run2}
+mc_sample = {**mc_sample_run2 }
