@@ -10,33 +10,30 @@
 ###############################################################################
 
 from ..datasets import legacy_run2_pidcalib_datasets as ds
+from ..mc_datasets import lb2jpsipk_run2sim09_datsets as mc_run2sim09
+
 from itertools import product
 
+probnn_responses = ["pi", "K", "p", "e", "mu", "piNotK", "piNotKp", "KNotpi", "KNotpip", "pNotK", "pNotpiK"]
+
+def brunel_aliases(year) : 
+    """
+      Define aliases for Brunel variables in 2017, 2018 samples
+      to point to Online versions. 
+    """
+    if year in ["2017", "2018"] : 
+        return { "Brunel_MC15TuneV1_ProbNN" + var : "MC15TuneV1_ProbNN" + var for var in probnn_responses }
+    else : return {}
+
+probnn_responses_mc = ["pi", "K", "p"]
+brunel_aliases_mc = { "Brunel_MC15TuneV1_ProbNN" + var : "MC15TuneV1_ProbNN" + var for var in probnn_responses_mc }
+
 def trees(year) : 
   #return [ ("Lam0" + ("LL" if year in ["2017", "2018"] else "") + \
   #            f"_{i}{j}Tuple/DecayTuple") for i, j in product(["", "HPT_", "VHPT_"], ["P", "Pbar"]) ]
   return [ (f"Lam0LL_{i}{j}Tuple/DecayTree") for i, j in product(["", "HPT_", "VHPT_"], ["P", "Pbar"]) ]
 
-sample = {
-  f"{pol}_{year}" : { 
-    "sample" : ds[f"{pol}_{year}"], 
-    "branches" : [ 
-      "probe_Brunel_PT", 
-      "probe_Brunel_ETA", 
-      "nTracks_Brunel", 
-      "probe_sWeight" 
-    ], 
-    "trees" : trees(year), 
-    "variables" : [
-                   "CombDLLK", "CombDLLmu", "CombDLLe", "CombDLLp", 
-                   "MC15TuneV1_ProbNNpi", "MC15TuneV1_ProbNNK", "MC15TuneV1_ProbNNp", 
-                   "MC15TuneV1_ProbNNe", "MC15TuneV1_ProbNNmu", 
-                   "MC15TuneV1_ProbNNpiNotK", "MC15TuneV1_ProbNNpiNotKp", 
-                   "MC15TuneV1_ProbNNKNotpi", "MC15TuneV1_ProbNNKNotpip", 
-                   "MC15TuneV1_ProbNNpNotK", "MC15TuneV1_ProbNNpNotpiK", 
-                  ], 
-    #"cut" : "(L0_ENDVERTEX_Z>0 & L0_ENDVERTEX_Z<100)",
-    "cut" : "((L0_BPVLTCHI2>0) & (L0_BPVLTCHI2<1e3))",
+common_params = {
     "smear" : [ None, None, (-0.5, 0.5) ], 
     "transform" : [ 
       "np.log10(x)",   # pT transformation
@@ -56,6 +53,44 @@ sample = {
       "default" : [2., 4., 4.], 
       "syst1"   : [3., 6., 6.], 
     }
+}
+
+sample = {
+  f"{pol}_{year}" : { 
+    "sample" : ds[f"{pol}_{year}"], 
+    "branches" : [ 
+      "probe_Brunel_PT", 
+      "probe_Brunel_ETA", 
+      "nTracks_Brunel", 
+      "probe_sWeight" 
+    ], 
+    "trees" : trees(year), 
+    "variables" : ["CombDLLK", "CombDLLmu", "CombDLLe", "CombDLLp"] + 
+                  [ f"{b}MC15TuneV1_ProbNN{i}" for b, i in product(["", "Brunel_"], probnn_responses) ], 
+    "aliases" : brunel_aliases(year), 
+    #"cut" : "(L0_ENDVERTEX_Z>0 & L0_ENDVERTEX_Z<100)",
+    "cut" : "((L0_BPVLTCHI2>0) & (L0_BPVLTCHI2<1e3))",
+    **common_params
   } 
   for pol in ["MagUp", "MagDown"] for year in ["2015", "2016", "2017", "2018"]
 }
+
+mc_sample_run2 = {
+  f"Sim09_{pol}_{year}" : {
+    "sample" : mc_run2sim09[f"{pol}_{year}"], 
+    "prefix" : "p", 
+    "branches" : [
+      "p_PT", 
+      "p_ETA", 
+      "nTracks",
+    ], 
+    "trees" : ["lc/nt"], 
+    "variables" : [ f"{b}MC15TuneV1_ProbNN{i}" for b, i in product(["", "Brunel_"], probnn_responses_mc) ] + 
+                  ["CombDLLp", "CombDLLK"], 
+    "aliases" : brunel_aliases_mc, 
+    **common_params, 
+  }
+  for pol in ["MagUp", "MagDown"] for year in ["2015", "2016", "2017", "2018"]
+}
+
+mc_sample = {**mc_sample_run2 }
