@@ -12,6 +12,17 @@
 from ..datasets import legacy_run2_pidcalib_datasets as ds
 from itertools import product
 
+probnn_responses = ["pi", "K", "p", "e", "mu", "piNotK", "piNotKp", "KNotpi", "KNotpip", "pNotK", "pNotpiK"]
+
+def brunel_aliases(year) : 
+    """
+      Define aliases for Brunel variables in 2017, 2018 samples
+      to point to Online versions. 
+    """
+    if year in ["2017", "2018"] : 
+        return { "Brunel_MC15TuneV1_ProbNN" + var : "MC15TuneV1_ProbNN" + var for var in probnn_responses }
+    else : return {}
+
 def trees(year) : 
   #return [ ("Lam0" + ("LL" if year in ["2017", "2018"] else "") + \
   #            f"_{i}{j}Tuple/DecayTuple") for i, j in product(["", "HPT_", "VHPT_"], ["P", "Pbar"]) ]
@@ -27,14 +38,9 @@ sample = {
       "probe_sWeight" 
     ], 
     "trees" : trees(year), 
-    "variables" : [
-                   "CombDLLK", "CombDLLmu", "CombDLLe", "CombDLLp", 
-                   "MC15TuneV1_ProbNNpi", "MC15TuneV1_ProbNNK", "MC15TuneV1_ProbNNp", 
-                   "MC15TuneV1_ProbNNe", "MC15TuneV1_ProbNNmu", 
-                   "MC15TuneV1_ProbNNpiNotK", "MC15TuneV1_ProbNNpiNotKp", 
-                   "MC15TuneV1_ProbNNKNotpi", "MC15TuneV1_ProbNNKNotpip", 
-                   "MC15TuneV1_ProbNNpNotK", "MC15TuneV1_ProbNNpNotpiK", 
-                  ], 
+    "variables" : ["CombDLLK", "CombDLLmu", "CombDLLe", "CombDLLp"] + 
+                  [ f"{b}MC15TuneV1_ProbNN{i}" for b, i in product(["", "Brunel_"], probnn_responses) ], 
+    "aliases" : brunel_aliases(year), 
     #"cut" : "(L0_ENDVERTEX_Z>0 & L0_ENDVERTEX_Z<100)",
     "cut" : "((L0_BPVLTCHI2>0) & (L0_BPVLTCHI2<1e3) & (probe_PIDp>0))",
     "smear" : [ None, None, (-0.5, 0.5) ], 
